Testing the layout option
-------------------------

.. report:: TestCases.LayoutTest
   :render: line-plot
   :transform: histogram
   :layout: row
   :mpl-rc: figure.figsize=(3,3)
   :as-lines:

   Row layout

.. report:: TestCases.LayoutTest
   :render: line-plot
   :transform: histogram
   :layout: column
   :mpl-rc: figure.figsize=(3,3)
   :as-lines:

   Column layout

.. report:: TestCases.LayoutTest
   :render: line-plot
   :transform: histogram
   :layout: column-2
   :mpl-rc: figure.figsize=(3,3)
   :as-lines:

   Column layout with two columns

.. report:: TestCases.LayoutTest
   :render: line-plot
   :transform: histogram
   :layout: grid
   :mpl-rc: figure.figsize=(3,3)
   :as-lines:

   Grid layout



